Use Case:  Provide feedback on content
======================================

Actor
-----

Site Visitor

Assumptions
-----------

* The Site Manager has configured the permissions of the site
  to allow anonymous users to discuss published content

  **or**

  the Site Visitor has logged into the CMF (see :doc:`LoginAsMember`).

* The Site Manager has enabled discussion for the content type of the item
  for which the Site Visitor wishes to provide feedback.

Procedure
---------

1. Navigate to the content on which you wish to provide feedback

2. Select 'Reply' from the actions box. The system will display the reply
   form for the object.

   **Reply Title** --
     an input field for the title of your feedback; initially, the field will
     have the title of the object to which you are replying.

   **Reply** --
     a textarea for entering feedback.

   **Preview** --
     a submit button which permits you to preview your reply before
     submitting it.

   **Reply** --
     a submit button for creating your reply.

3. Update the title, if desired, and enter your comment into the textarea.

4. Click the "Preview" button to check that your reply will be formatted as
   you desire. If not, return to the reply form using the "Edit" button.

5. Click the "Reply" button. The system will append your comment to the
   thread of replies on the target object.
